==> punbb-1.3.tar.gz: punbb-1.3/lang/English/forum.php <==
<?php

// Language definitions used in viewforum.php
$lang_forum = array(

'Forum subtitle'			=>	'%1$s in this forum with details of %2$s.',
'Search subtitle'			=>	'%1$s found with details of %2$s.',
'Topics'					=>	'Topics',
'topics'					=>	'topics',
'Reply'						=>	'Reply',
'Replies'					=>	'Replies',
'Forum'						=>	'Forum',
'reply'						=>	'reply',
'replies'					=>	'replies',
'View'						=>	'View',
'Views'						=>	'Views',
'views'						=>	'views',
'view'						=>	'view',
'Last post'					=>	'Last post',
'last post'					=>	'last post',
'Select topic'				=>	'Select topic: %s.',
'No replies info'			=>	'No reply information',
'No views info'				=>	'No viewing information',
'No lastpost info'			=>	'No last post information',
'by poster'					=>	'by %s',
'Item status'				=>	'%s :',
'Topic starter'				=>	'by %s',
'New posts'					=>	'New posts',
'Topic navigation'			=>	'( %s )',
'Location'					=>	'Found in forum : %s',
'Pages'						=>	'Pages',
'Post topic'				=>	'Post new topic',
'Login to post'				=>	'You must %1$s or %2$s to post a new topic',
'No permission'				=>	'Sorry! no permission to post new topics',
'Moved'						=>	'Moved:',
'Sticky'					=>	'Sticky',
'Closed'					=>	'Closed',
'Empty forum'				=>	'Empty forum',
'No topics'					=>	'No topics have been posted',
'First topic nag'			=>	'Be the first to post a topic in this forum.',
'You posted indicator'		=>	'·',
'Permalink forum'			=>	'Permanent link to this forum.',
'Forum options'				=>	'Forum options',
'Moderate forum'			=>	'Moderate forum',
'Mark forum read'			=>	'Mark forum as read',
'RSS forum feed'			=>	'RSS Forum Feed',
'New posts info'			=>	'Go to the first new post since your last visit.'

);

==> punbb-1.4.1.tar.gz: punbb-1.4.1/lang/English/forum.php <==
<?php

// Language definitions used in viewforum.php
$lang_forum = array(

'Forum subtitle'			=>	'%1$s in this forum with details of %2$s.',
'Search subtitle'			=>	'%1$s found with details of %2$s.',
'Topics'					=>	'Topics',
'topics'					=>	'topics',
'Reply'						=>	'Reply',
'Replies'					=>	'Replies',
'Forum'						=>	'Forum',
'reply'						=>	'reply',
'replies'					=>	'replies',
'View'						=>	'View',
'Views'						=>	'Views',
'views'						=>	'views',
'view'						=>	'view',
'Last post'					=>	'Last post',
'last post'					=>	'last post',
'Select topic'				=>	'Select topic: %s.',
'No replies info'			=>	'No reply information',
'No views info'				=>	'No viewing information',
'No lastpost info'			=>	'No last post information',
'by poster'					=>	'by %s',
'Item status'				=>	'%s:',
'Topic starter'				=>	'by <cite>%s</cite>',
'New posts'					=>	'New posts',
'Topic navigation'			=>	'( %s )',
'Location'					=>	'Found in forum: %s',
'Pages'						=>	'Pages',
'Post topic'				=>	'Post new topic',
'Login to post'				=>	'You must %1$s or %2$s to post a new topic',
'No permission'				=>	'Sorry! no permission to post new topics',
'Moved'						=>	'Moved',
'Sticky'					=>	'Sticky',
'Closed'					=>	'Closed',
'Empty forum'				=>	'Empty forum',
'No topics'					=>	'No topics have been posted',
'First topic nag'			=>	'Be the first to post a topic in this forum.',
'You posted indicator'		=>	'·',
'Permalink forum'			=>	'Permanent link to this forum.',
'Forum options'				=>	'Forum options',
'Moderate forum'			=>	'Moderate forum',
'Mark forum read'			=>	'Mark forum as read',
'RSS forum feed'			=>	'RSS forum feed',
'New posts info'			=>	'Go to the first new post since your last visit.',
'Unsubscribe'				=>	'Unsubscribe',
'Subscribe'					=>	'Subscribe',
'Subscribe info'			=>	'Receive email notification of new topics.',

);
